==> duiba-goods-center-api-0.0.1-20211204.152830-72-sources.jar: cn/com/duiba/cloud/duiba/goods/center/api/dto/goods/GoodsAttributeDto.java <==
package cn.com.duiba.cloud.duiba.goods.center.api.dto.goods;

import cn.com.duiba.cloud.duiba.goods.center.api.constant.AttributeTypeEnum;
import cn.com.duiba.cloud.duiba.goods.center.api.constant.GeneralTypeEnum;
import cn.com.duiba.cloud.duiba.goods.center.api.dto.BaseDto;
import cn.com.duiba.cloud.duiba.goods.center.api.dto.GeneralBiz;
import cn.com.duiba.cloud.duiba.goods.center.api.util.GoodsSnapshotUtil;
import com.alibaba.fastjson.annotation.JSONField;
import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;

/**
 * @author zsp (zengshuiping@duiba.com.cn)
 * @date 2021/11/15 10:50 上午
 */
@Setter
@Getter
public class GoodsAttributeDto extends BaseDto implements Serializable, GeneralBiz {
    private static final long serialVersionUID = 1L;

    /**
     * 属性id
     */
    private Long attrId;
    /**
     * 属性名
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private String attrName;
    /**
     * 属性值
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private String attrValue;
    /**
     * 属性值Id
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private Long attrValueId;
    /**
     * 属性类型(1:参数属性,2:sku属性)
     *
     * @see AttributeTypeEnum
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private Integer attrType;
    /**
     * 排序
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private Long sort;

    /**
     * spuID或skuID
     */
    private Long generalId;
    /**
     * 类型(1:spu;2:sku)
     *
     * @see GeneralTypeEnum
     */
    private Integer generalType;
}

==> duiba-goods-center-api-0.0.2-20220118.103930-32-sources.jar: cn/com/duiba/cloud/duiba/goods/center/api/dto/goods/GoodsAttributeDto.java <==
package cn.com.duiba.cloud.duiba.goods.center.api.dto.goods;

import cn.com.duiba.cloud.duiba.goods.center.api.constant.AttributeTypeEnum;
import cn.com.duiba.cloud.duiba.goods.center.api.constant.GeneralTypeEnum;
import cn.com.duiba.cloud.duiba.goods.center.api.dto.BaseDto;
import cn.com.duiba.cloud.duiba.goods.center.api.dto.GeneralBiz;
import cn.com.duiba.cloud.duiba.goods.center.api.util.GoodsSnapshotUtil;
import cn.com.duiba.wolf.utils.SwitchUtils;
import com.alibaba.fastjson.annotation.JSONField;
import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;

/**
 * @author zsp (zengshuiping@duiba.com.cn)
 * @date 2021/11/15 10:50 上午
 */
@Setter
@Getter
public class GoodsAttributeDto extends BaseDto implements Serializable, GeneralBiz {
    private static final long serialVersionUID = 1L;

    /**
     * 该属性/规格是否包含图片
     */
    public static final int SWITCH_IMG = 0;

    /**
     * 属性id
     */
    private Long attrId;
    /**
     * 属性名
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private String attrName;
    /**
     * 属性值
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private String attrValue;
    /**
     * 属性值Id
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private Long attrValueId;
    /**
     * 属性类型(1:参数属性,2:sku属性)
     *
     * @see AttributeTypeEnum
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private Integer attrType;
    /**
     * 排序
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private Long sort;

    /**
     * spuID或skuID
     */
    private Long generalId;
    /**
     * 类型(1:spu;2:sku)
     *
     * @see GeneralTypeEnum
     */
    private Integer generalType;

    /**
     * 开关集合，通过移位运算得到
     */
    private Integer attrSwitches;


    /**
     * 该属性是否是含图片属性
     */
    public boolean hasImage() {
        return SwitchUtils.switchIsOpen(getAttrSwitches(), SWITCH_IMG);
    }

    public void setHasImage(boolean hasImage) {
        setAttrSwitches(hasImage ? SwitchUtils.openSwitch(getAttrSwitches(), SWITCH_IMG) : SwitchUtils.closeSwitch(getAttrSwitches(), SWITCH_IMG));
    }
}
